@@ -112,7 +112,7 @@ func (b *Browser) Init(ctx context.Context) error {
 	if row == 0 && b.GetRowCount() > 0 {
 		b.Select(1, 0)
 	}
-	b.GetModel().SetRefreshRate(time.Duration(b.App().Config.K9s.GetRefreshRate()) * time.Second)
+	b.GetModel().SetRefreshRate(b.App().Config.K9s.RefreshDuration())
 
 	b.CmdBuff().SetSuggestionFn(b.suggestFilter())
 
@@ -170,6 +170,7 @@ func (b *Browser) Start() {
 	}
 
 	b.Stop()
+	b.firstView.Store(0) // Reset first view counter on each start
 	b.GetModel().AddListener(b)
 	b.Table.Start()
 	b.CmdBuff().AddListener(b)
@@ -196,13 +197,13 @@ func (b *Browser) Stop() {
 	b.Table.Stop()
 }
 
-func (b *Browser) SetFilter(s string) {
-	b.CmdBuff().SetText(s, "")
+func (b *Browser) SetFilter(s string, wipe bool) {
+	b.CmdBuff().SetText(s, "", wipe)
 }
 
-func (b *Browser) SetLabelSelector(sel labels.Selector) {
+func (b *Browser) SetLabelSelector(sel labels.Selector, wipe bool) {
 	if sel != nil {
-		b.CmdBuff().SetText(sel.String(), "")
+		b.CmdBuff().SetText(sel.String(), "", wipe)
 	}
 	b.GetModel().SetLabelSelector(sel)
 }
@@ -213,7 +214,7 @@ func (*Browser) BufferChanged(_, _ string) {}
 // BufferCompleted indicates input was accepted.
 func (b *Browser) BufferCompleted(text, _ string) {
 	if internal.IsLabelSelector(text) {
-		if sel, err := ui.TrimLabelSelector(text); err == nil {
+		if sel, err := ui.ExtractLabelSelector(text); err == nil {
 			b.GetModel().SetLabelSelector(sel)
 		}
 	} else {
@@ -301,7 +302,8 @@ func (b *Browser) TableNoData(mdata *model1.TableData) {
 	if !b.app.ConOK() || cancel == nil || !b.app.IsRunning() {
 		return
 	}
-	if b.firstView.Load() == 0 {
+	// Skip warning on first view or if table data is empty (likely during initialization)
+	if b.firstView.Load() == 0 || mdata.Empty() {
 		b.firstView.Add(1)
 		return
 	}
@@ -573,7 +575,7 @@ func (b *Browser) defaultContext() context.Context {
 	ctx = context.WithValue(ctx, internal.KeyGVR, b.GVR())
 	ctx = context.WithValue(ctx, internal.KeyPath, b.Path)
 	if internal.IsLabelSelector(b.CmdBuff().GetText()) {
-		if sel, err := ui.TrimLabelSelector(b.CmdBuff().GetText()); err == nil {
+		if sel, err := ui.ExtractLabelSelector(b.CmdBuff().GetText()); err == nil {
 			ctx = context.WithValue(ctx, internal.KeyLabels, sel)
 		}
 	}
