@@ -4,6 +4,8 @@
 package cmd
 
 import (
+	"maps"
+	"slices"
 	"strings"
 )
 
@@ -27,9 +29,6 @@ func newArgs(p *Interpreter, aa []string) args {
 	for i := 0; i < len(aa); i++ {
 		a := strings.TrimSpace(aa[i])
 		switch {
-		case strings.Index(a, contextFlag) == 0:
-			arguments[contextKey] = a[1:]
-
 		case strings.Index(a, fuzzyFlag) == 0:
 			if a == fuzzyFlag {
 				i++
@@ -49,25 +48,29 @@ func newArgs(p *Interpreter, aa []string) args {
 				arguments[filterKey] = strings.ToLower(a[1:])
 			}
 
-		case strings.Contains(a, labelFlag):
-			if ll := ToLabels(a); len(ll) != 0 {
-				arguments[labelKey] = strings.ToLower(a)
-			}
+		case isLabelArg(a):
+			arguments[labelKey] = strings.ToLower(a)
+
+		case strings.Index(a, contextFlag) == 0:
+			arguments[contextKey] = a[1:]
 
 		default:
 			switch {
 			case p.IsContextCmd():
 				arguments[contextKey] = a
+
 			case p.IsDirCmd():
 				if _, ok := arguments[topicKey]; !ok {
 					arguments[topicKey] = a
 				}
+
 			case p.IsXrayCmd():
 				if _, ok := arguments[topicKey]; ok {
 					arguments[nsKey] = strings.ToLower(a)
 				} else {
 					arguments[topicKey] = strings.ToLower(a)
 				}
+
 			default:
 				arguments[nsKey] = strings.ToLower(a)
 			}
@@ -77,6 +80,23 @@ func newArgs(p *Interpreter, aa []string) args {
 	return arguments
 }
 
+func (a args) String() string {
+	ss := make([]string, 0, len(a))
+	kk := maps.Keys(a)
+	for _, k := range slices.Sorted(kk) {
+		v := a[k]
+		switch k {
+		case filterKey:
+			v = filterFlag + v
+		case contextKey:
+			v = contextFlag + v
+		}
+		ss = append(ss, v)
+	}
+
+	return strings.Join(ss, " ")
+}
+
 func (a args) hasFilters() bool {
 	_, fok := a[filterKey]
 	_, zok := a[fuzzyKey]
@@ -84,3 +104,13 @@ func (a args) hasFilters() bool {
 
 	return fok || zok || lok
 }
+
+func isLabelArg(arg string) bool {
+	for _, flag := range labelFlags {
+		if strings.Contains(arg, flag) {
+			return true
+		}
+	}
+
+	return false
+}
