@@ -15,6 +15,7 @@ func Test_viewMetaFor(t *testing.T) {
 	uu := map[string]struct {
 		cmd string
 		gvr *client.GVR
+		p   *cmd.Interpreter
 		err error
 	}{
 		"empty": {
@@ -23,27 +24,37 @@ func Test_viewMetaFor(t *testing.T) {
 			err: errors.New("`` command not found"),
 		},
 
-		"toast-cmd": {
+		"toast": {
 			cmd: "v1/pd",
 			gvr: client.PodGVR,
 			err: errors.New("`v1/pd` command not found"),
 		},
 
-		"gvr-cmd": {
+		"gvr": {
 			cmd: "v1/pods",
 			gvr: client.PodGVR,
+			p:   cmd.NewInterpreter("v1/pods"),
 			err: errors.New("blah"),
 		},
 
-		"alias-cmd": {
+		"short-name": {
 			cmd: "po",
 			gvr: client.PodGVR,
+			p:   cmd.NewInterpreter("v1/pods"),
 			err: errors.New("blee"),
 		},
 
-		"full-cmd": {
+		"custom-alias": {
 			cmd: "pdl",
 			gvr: client.PodGVR,
+			p:   cmd.NewInterpreter("v1/pods @fred app=blee default"),
+			err: errors.New("blee"),
+		},
+
+		"inception": {
+			cmd: "pdal blee",
+			gvr: client.PodGVR,
+			p:   cmd.NewInterpreter("v1/pods @fred app=blee blee"),
 			err: errors.New("blee"),
 		},
 	}
@@ -55,16 +66,18 @@ func Test_viewMetaFor(t *testing.T) {
 	}
 	c.alias.Define(client.PodGVR, "po", "pod", "pods", client.PodGVR.String())
 	c.alias.Define(client.NewGVR("pod default"), "pd")
-	c.alias.Define(client.NewGVR("pod default app=blee @fred"), "pdl")
+	c.alias.Define(client.NewGVR("pod @fred app=blee default"), "pdl")
+	c.alias.Define(client.NewGVR("pdl"), "pdal")
 
 	for k, u := range uu {
 		t.Run(k, func(t *testing.T) {
 			p := cmd.NewInterpreter(u.cmd)
-			gvr, _, err := c.viewMetaFor(p)
+			gvr, _, acmd, err := c.viewMetaFor(p)
 			if err != nil {
 				assert.Equal(t, u.err.Error(), err.Error())
 			} else {
 				assert.Equal(t, u.gvr, gvr)
+				assert.Equal(t, u.p, acmd)
 			}
 		})
 	}
